FmtRenderError

Enum FmtRenderError 

pub enum FmtRenderError<R> {
    Render(R),
    Fmt(Error),
}
An error while rendering a compiled template string into a fmt::Write.

The Render variant is emitted by the particular Manifest implementation which is used to parse the template string expressions. It is the associated Manifest::Error type.

For infallible rendering, there is a is a From<FmtRenderError<Infallible>> implementation for fmt::Error.

Variants



Render(R)

A value in an expression could not be rendered.



Fmt(Error)

An error occured while writing to a fmt::Write.