pub enum IORenderError<R> {
Render(R),
IO(Error),
}Expand description
An error while rendering a compiled template string into an io::Write.
The Render variant is emitted by the particular
Manifest implementation which is used to parse the template string
expressions.
It is the associated Manifest::Error type.
For infallible rendering, there is a is a From<IORenderError<Infallible>> implementation for io::Error.
Variants
Render(R)
A value in an expression could not be rendered.
IO(Error)
An error occured while writing to an io::Write.