pub enum ParseBoundedIntError {
OutOfRange(usize),
ParseError(ParseIntError),
}Expand description
An error which may occur while parsing a BoundedInt from a string.
Variants
OutOfRange(usize)
Parsed a valid usize, which is out of range.
ParseError(ParseIntError)
The string is not a valid usize
Implementations
Sourceimpl ParseBoundedIntError
impl ParseBoundedIntError
Sourcepub const fn kind(&self) -> IntErrorKind
pub const fn kind(&self) -> IntErrorKind
Outputs the detailed cause of failed parsing.